@@ -54,7 +54,7 @@ typedef struct _RunInThreadClosure RunInThreadClosure;
 
 struct _EBookClientPrivate {
 	EDBusAddressBook *dbus_proxy;
-	EDataBook *direct_book;
+	EBookBackend *direct_backend;
 	guint name_watcher_id;
 
 	gulong dbus_proxy_error_handler_id;
@@ -162,13 +162,6 @@ run_in_thread_closure_free (RunInThreadClosure *run_in_thread_closure)
 	g_slice_free (RunInThreadClosure, run_in_thread_closure);
 }
 
-static void
-weak_ref_free (GWeakRef *weak_ref)
-{
-	g_weak_ref_set (weak_ref, NULL);
-	g_slice_free (GWeakRef, weak_ref);
-}
-
 /*
  * Well-known book backend properties:
  * @BOOK_BACKEND_PROPERTY_REQUIRED_FIELDS: Retrieves comma-separated list
@@ -185,6 +178,104 @@ weak_ref_free (GWeakRef *weak_ref)
  *   @CLIENT_BACKEND_PROPERTY_CACHE_DIR, @CLIENT_BACKEND_PROPERTY_CAPABILITIES
  */
 
+static EBookBackend *
+book_client_load_direct_backend (ESourceRegistry *registry,
+                                 ESource *source,
+                                 const gchar *backend_path,
+                                 const gchar *backend_name,
+                                 const gchar *config,
+                                 GError **error)
+{
+	static GHashTable *modules_table = NULL;
+	G_LOCK_DEFINE_STATIC (modules_table);
+
+	EModule *module;
+	GType factory_type;
+	EBookBackend *backend;
+	EBookBackendFactoryClass *factory_class;
+
+	g_return_val_if_fail (backend_path != NULL, NULL);
+	g_return_val_if_fail (backend_name != NULL, NULL);
+
+	G_LOCK (modules_table);
+
+	if (modules_table == NULL)
+		modules_table = g_hash_table_new (
+			(GHashFunc) g_str_hash,
+			(GEqualFunc) g_str_equal);
+
+	module = g_hash_table_lookup (modules_table, backend_path);
+
+	if (module == NULL) {
+		module = e_module_new (backend_path);
+		g_hash_table_insert (
+			modules_table, g_strdup (backend_path), module);
+	}
+
+	G_UNLOCK (modules_table);
+
+	if (!g_type_module_use (G_TYPE_MODULE (module))) {
+		g_set_error (
+			error, E_CLIENT_ERROR,
+			E_CLIENT_ERROR_OTHER_ERROR,
+			"Failed to use EModule at path '%s'",
+			backend_path);
+		return NULL;
+	}
+
+	factory_type = g_type_from_name (backend_name);
+	if (factory_type == G_TYPE_INVALID) {
+		g_set_error (
+			error, E_CLIENT_ERROR,
+			E_CLIENT_ERROR_OTHER_ERROR,
+			"Failed to get backend factory '%s' "
+			"from EModule at path '%s'",
+			backend_name, backend_path);
+		g_type_module_unuse (G_TYPE_MODULE (module));
+		return NULL;
+	}
+
+	factory_class = g_type_class_ref (factory_type);
+
+	backend = g_object_new (
+		factory_class->backend_type,
+		"registry", registry,
+		"source", source, NULL);
+
+	/* The backend must be configured for direct access
+	 * before calling g_initable_init(), since backends
+	 * can access their content in initable_init(). */
+	e_book_backend_configure_direct (backend, config);
+
+	if (!g_initable_init (G_INITABLE (backend), NULL, error)) {
+		g_type_module_unuse (G_TYPE_MODULE (module));
+		g_object_unref (backend);
+		backend = NULL;
+	}
+
+	g_type_class_unref (factory_class);
+
+	/* XXX Until backend methods can be updated, EBookBackend
+	 *     still needs an EDataBook to catch "respond" calls. */
+	if (backend != NULL) {
+		EDataBook *data_book;
+
+		data_book = g_initable_new (
+			E_TYPE_DATA_BOOK, NULL, error,
+			"backend", backend, NULL);
+
+		if (data_book == NULL) {
+			g_type_module_unuse (G_TYPE_MODULE (module));
+			g_object_unref (backend);
+			backend = NULL;
+		}
+
+		g_clear_object (&data_book);
+	}
+
+	return backend;
+}
+
 static gpointer
 book_client_dbus_thread (gpointer user_data)
 {
@@ -355,37 +446,50 @@ book_client_emit_backend_property_changed_idle_cb (gpointer user_data)
 static void
 book_client_dbus_proxy_error_cb (EDBusAddressBook *dbus_proxy,
                                  const gchar *error_message,
-                                 EClient *client)
+                                 GWeakRef *client_weak_ref)
 {
-	GSource *idle_source;
-	GMainContext *main_context;
-	SignalClosure *signal_closure;
+	EClient *client;
 
-	signal_closure = g_slice_new0 (SignalClosure);
-	g_weak_ref_set (&signal_closure->client, client);
-	signal_closure->error_message = g_strdup (error_message);
+	client = g_weak_ref_get (client_weak_ref);
 
-	main_context = e_client_ref_main_context (client);
+	if (client != NULL) {
+		GSource *idle_source;
+		GMainContext *main_context;
+		SignalClosure *signal_closure;
 
-	idle_source = g_idle_source_new ();
-	g_source_set_callback (
-		idle_source,
-		book_client_emit_backend_error_idle_cb,
-		signal_closure,
-		(GDestroyNotify) signal_closure_free);
-	g_source_attach (idle_source, main_context);
-	g_source_unref (idle_source);
+		signal_closure = g_slice_new0 (SignalClosure);
+		g_weak_ref_set (&signal_closure->client, client);
+		signal_closure->error_message = g_strdup (error_message);
 
-	g_main_context_unref (main_context);
+		main_context = e_client_ref_main_context (client);
+
+		idle_source = g_idle_source_new ();
+		g_source_set_callback (
+			idle_source,
+			book_client_emit_backend_error_idle_cb,
+			signal_closure,
+			(GDestroyNotify) signal_closure_free);
+		g_source_attach (idle_source, main_context);
+		g_source_unref (idle_source);
+
+		g_main_context_unref (main_context);
+
+		g_object_unref (client);
+	}
 }
 
 static void
 book_client_dbus_proxy_notify_cb (EDBusAddressBook *dbus_proxy,
                                   GParamSpec *pspec,
-                                  EClient *client)
+                                  GWeakRef *client_weak_ref)
 {
+	EClient *client;
 	const gchar *backend_prop_name = NULL;
 
+	client = g_weak_ref_get (client_weak_ref);
+	if (client == NULL)
+		return;
+
 	if (g_str_equal (pspec->name, "cache-dir")) {
 		backend_prop_name = CLIENT_BACKEND_PROPERTY_CACHE_DIR;
 	}
@@ -457,6 +561,8 @@ book_client_dbus_proxy_notify_cb (EDBusAddressBook *dbus_proxy,
 
 		g_main_context_unref (main_context);
 	}
+
+	g_object_unref (client);
 }
 
 static void
@@ -524,10 +630,9 @@ book_client_dispose (GObject *object)
 		priv->dbus_proxy = NULL;
 	}
 
-	if (priv->direct_book != NULL) {
-		e_data_book_close_sync (priv->direct_book, NULL, NULL);
-		g_object_unref (priv->direct_book);
-		priv->direct_book = NULL;
+	if (priv->direct_backend != NULL) {
+		g_object_unref (priv->direct_backend);
+		priv->direct_backend = NULL;
 	}
 
 	/* Chain up to parent's dispose() method. */
@@ -719,7 +824,6 @@ book_client_init_in_dbus_thread (GSimpleAsyncResult *simple,
 	EDBusAddressBookFactory *factory_proxy;
 	GDBusConnection *connection;
 	GDBusProxy *proxy;
-	GWeakRef *weak_ref;
 	EClient *client;
 	ESource *source;
 	const gchar *uid;
@@ -809,28 +913,29 @@ book_client_init_in_dbus_thread (GSimpleAsyncResult *simple,
 
 	g_dbus_proxy_set_default_timeout (proxy, DBUS_PROXY_TIMEOUT_MS);
 
-	/* XXX Wishing for g_weak_ref_new() / g_weak_ref_free() here. */
-	weak_ref = g_slice_new0 (GWeakRef);
-	g_weak_ref_set (weak_ref, client);
-
 	priv->name_watcher_id = g_bus_watch_name_on_connection (
 		connection,
 		g_dbus_proxy_get_name (proxy),
 		G_BUS_NAME_WATCHER_FLAGS_NONE,
 		(GBusNameAppearedCallback) NULL,
 		(GBusNameVanishedCallback) book_client_name_vanished_cb,
-		weak_ref, (GDestroyNotify) weak_ref_free);
+		e_weak_ref_new (client),
+		(GDestroyNotify) e_weak_ref_free);
 
-	handler_id = g_signal_connect_object (
+	handler_id = g_signal_connect_data (
 		proxy, "error",
 		G_CALLBACK (book_client_dbus_proxy_error_cb),
-		client, 0);
+		e_weak_ref_new (client),
+		(GClosureNotify) e_weak_ref_free,
+		0);
 	priv->dbus_proxy_error_handler_id = handler_id;
 
-	handler_id = g_signal_connect_object (
+	handler_id = g_signal_connect_data (
 		proxy, "notify",
 		G_CALLBACK (book_client_dbus_proxy_notify_cb),
-		client, 0);
+		e_weak_ref_new (client),
+		(GClosureNotify) e_weak_ref_free,
+		0);
 	priv->dbus_proxy_notify_handler_id = handler_id;
 
 	/* Initialize our public-facing GObject properties. */
@@ -1246,14 +1351,14 @@ e_book_client_connect_direct_sync (ESourceRegistry *registry,
 	backend_name = e_dbus_direct_book_get_backend_name (direct_config);
 	config = e_dbus_direct_book_get_backend_config (direct_config);
 
-	if (backend_path && backend_path[0] &&
-	    backend_name && backend_name[0]) {
-		priv->direct_book = e_data_book_new_direct (
+	if (backend_path != NULL && *backend_path != '\0' &&
+	    backend_name != NULL && *backend_name != '\0') {
+		priv->direct_backend = book_client_load_direct_backend (
 			registry, source,
 			backend_path,
 			backend_name,
 			config, &local_error);
-		if (!priv->direct_book) {
+		if (local_error != NULL) {
 			g_warning (
 				"Failed to open addressbook in direct read "
 				"access mode, falling back to normal read "
@@ -1270,16 +1375,23 @@ e_book_client_connect_direct_sync (ESourceRegistry *registry,
 
 	g_object_unref (direct_config);
 
-	/* We have to perform the opeining of the direct book separately
+	/* We have to perform the opening of the direct backend separately
 	 * from the EClient->open() implementation, because the direct
-	 * book does not exist yet
-	 */
-	if (priv->direct_book &&
-	    !e_data_book_open_sync (priv->direct_book, cancellable, error)) {
-		g_warning (
-			"Unable to open direct read access book, "
-			"falling back to normal read access mode");
-		g_clear_object (&priv->direct_book);
+	 * backend does not exist yet. */
+	if (priv->direct_backend != NULL) {
+		gboolean success;
+
+		/* Direct backend is not using D-Bus (obviously),
+		 * so no need to strip D-Bus info from the error. */
+		success = e_book_backend_open_sync (
+			priv->direct_backend, cancellable, error);
+
+		if (!success) {
+			g_warning (
+				"Unable to open direct read access book, "
+				"falling back to normal read access mode");
+			g_clear_object (&priv->direct_backend);
+		}
 	}
 
 	return client;
@@ -2680,12 +2792,23 @@ e_book_client_get_contact_sync (EBookClient *client,
 	g_return_val_if_fail (uid != NULL, FALSE);
 	g_return_val_if_fail (out_contact != NULL, FALSE);
 
-	if (client->priv->direct_book != NULL) {
+	if (client->priv->direct_backend != NULL) {
+		EContact *contact;
+		gboolean success = FALSE;
+
 		/* Direct backend is not using D-Bus (obviously),
 		 * so no need to strip D-Bus info from the error. */
-		return e_data_book_get_contact_sync (
-			client->priv->direct_book, uid,
-			out_contact, cancellable, error);
+		contact = e_book_backend_get_contact_sync (
+			client->priv->direct_backend,
+			uid, cancellable, error);
+
+		if (contact != NULL) {
+			*out_contact = g_object_ref (contact);
+			g_object_unref (contact);
+			success = TRUE;
+		}
+
+		return success;
 	}
 
 	utf8_uid = e_util_utf8_make_valid (uid);
@@ -2865,12 +2988,29 @@ e_book_client_get_contacts_sync (EBookClient *client,
 	g_return_val_if_fail (sexp != NULL, FALSE);
 	g_return_val_if_fail (out_contacts != NULL, FALSE);
 
-	if (client->priv->direct_book != NULL) {
+	if (client->priv->direct_backend != NULL) {
+		GQueue queue = G_QUEUE_INIT;
+		GSList *list = NULL;
+		gboolean success;
+
 		/* Direct backend is not using D-Bus (obviously),
 		 * so no need to strip D-Bus info from the error. */
-		return e_data_book_get_contacts_sync (
-			client->priv->direct_book,
-			sexp, out_contacts, cancellable, error);
+		success = e_book_backend_get_contact_list_sync (
+			client->priv->direct_backend,
+			sexp, &queue, cancellable, error);
+
+		if (success) {
+			while (!g_queue_is_empty (&queue)) {
+				EContact *contact;
+
+				contact = g_queue_pop_head (&queue);
+				list = g_slist_prepend (list, contact);
+			}
+
+			*out_contacts = g_slist_reverse (list);
+		}
+
+		return success;
 	}
 
 	utf8_sexp = e_util_utf8_make_valid (sexp);
@@ -3059,12 +3199,29 @@ e_book_client_get_contacts_uids_sync (EBookClient *client,
 	g_return_val_if_fail (sexp != NULL, FALSE);
 	g_return_val_if_fail (out_contact_uids != NULL, FALSE);
 
-	if (client->priv->direct_book != NULL) {
+	if (client->priv->direct_backend != NULL) {
+		GQueue queue = G_QUEUE_INIT;
+		GSList *list = NULL;
+		gboolean success;
+
 		/* Direct backend is not using D-Bus (obviously),
 		 * so no need to strip D-Bus info from the error. */
-		return e_data_book_get_contacts_uids_sync (
-			client->priv->direct_book, sexp,
-			out_contact_uids, cancellable, error);
+		success = e_book_backend_get_contact_list_uids_sync (
+			client->priv->direct_backend,
+			sexp, &queue, cancellable, error);
+
+		if (success) {
+			while (!g_queue_is_empty (&queue)) {
+				gchar *uid;
+
+				uid = g_queue_pop_head (&queue);
+				list = g_slist_prepend (list, uid);
+			}
+
+			*out_contact_uids = g_slist_reverse (list);
+		}
+
+		return success;
 	}
 
 	utf8_sexp = e_util_utf8_make_valid (sexp);
@@ -3147,7 +3304,7 @@ book_client_get_view_in_dbus_thread (GSimpleAsyncResult *simple,
 			"client", client,
 			"connection", connection,
 			"object-path", object_path,
-			"direct-book", client->priv->direct_book,
+			"direct-backend", client->priv->direct_backend,
 			NULL);
 
 		/* Sanity check. */
