@@ -311,25 +311,13 @@ static void
 gpg_ctx_add_recipient (struct _GpgCtx *gpg,
                        const gchar *keyid)
 {
-	gchar *safe_keyid;
-
 	if (gpg->mode != GPG_CTX_MODE_ENCRYPT && gpg->mode != GPG_CTX_MODE_EXPORT)
 		return;
 
 	if (!gpg->recipients)
 		gpg->recipients = g_ptr_array_new ();
 
-	g_return_if_fail (keyid != NULL);
-
-	/* If the recipient looks like an email address,
-	 * enclose it in brackets to ensure an exact match. */
-	if (strchr (keyid, '@') != NULL) {
-		safe_keyid = g_strdup_printf ("<%s>", keyid);
-	} else {
-		safe_keyid = g_strdup (keyid);
-	}
-
-	g_ptr_array_add (gpg->recipients, safe_keyid);
+	g_ptr_array_add (gpg->recipients, g_strdup (keyid));
 }
 
 static void
@@ -451,33 +439,6 @@ gpg_ctx_free (struct _GpgCtx *gpg)
 	g_free (gpg);
 }
 
-static const gchar *
-gpg_ctx_get_executable_name (void)
-{
-	static gint index = -1;
-	const gchar *names[] = {
-		"gpg",
-		"gpg2",
-		NULL
-	};
-
-	if (index == -1) {
-		for (index = 0; names[index]; index++) {
-			gchar *path = g_find_program_in_path (names[index]);
-
-			if (path) {
-				g_free (path);
-				break;
-			}
-		}
-
-		if (!names[index])
-			index = 0;
-	}
-
-	return names[index];
-}
-
 #ifndef G_OS_WIN32
 
 static const gchar *
@@ -516,7 +477,7 @@ gpg_ctx_get_argv (struct _GpgCtx *gpg,
 	gint i;
 
 	argv = g_ptr_array_new ();
-	g_ptr_array_add (argv, (guint8 *) gpg_ctx_get_executable_name ());
+	g_ptr_array_add (argv, (guint8 *) "gpg");
 
 	g_ptr_array_add (argv, (guint8 *) "--verbose");
 	g_ptr_array_add (argv, (guint8 *) "--no-secmem-warning");
@@ -662,7 +623,7 @@ gpg_ctx_op_start (struct _GpgCtx *gpg,
 		}
 
 		/* run gpg */
-		execvp (gpg_ctx_get_executable_name (), (gchar **) argv->pdata);
+		execvp ("gpg", (gchar **) argv->pdata);
 		_exit (255);
 	} else if (gpg->pid < 0) {
 		g_ptr_array_free (argv, TRUE);
@@ -2166,8 +2127,8 @@ gpg_decrypt_sync (CamelCipherContext *context,
 	}
 
 	/* Report errors only if nothing was decrypted; missing sender's key used
-	 * for signature of a signed and encrypted messages causes GPG to return
-	 * failure, thus count with it.
+	   for signature of a signed and encrypted messages causes GPG to return
+	   failure, thus count with it.
 	 */
 	if (gpg_ctx_op_wait (gpg) != 0 && gpg->nodata) {
 		const gchar *diagnostics;
