@@ -21,6 +21,7 @@
 #include <errno.h>
 #include <string.h>
 
+#include "camel-imapx-command.h"
 #include "camel-imapx-folder.h"
 #include "camel-imapx-settings.h"
 #include "camel-imapx-stream.h"
@@ -349,6 +350,33 @@ imapx_update_store_summary (CamelFolder *folder)
 	}
 }
 
+gchar *
+camel_imapx_dup_uid_from_summary_index (CamelFolder *folder,
+                                        guint summary_index)
+{
+	CamelFolderSummary *summary;
+	GPtrArray *array;
+	gchar *uid = NULL;
+
+	g_return_val_if_fail (CAMEL_IS_FOLDER (folder), NULL);
+
+	summary = folder->summary;
+	g_return_val_if_fail (CAMEL_IS_FOLDER_SUMMARY (summary), NULL);
+
+	array = camel_folder_summary_get_array (summary);
+	g_return_val_if_fail (array != NULL, NULL);
+
+	if (summary_index < array->len) {
+		folder = camel_folder_summary_get_folder (summary);
+		camel_folder_sort_uids (folder, array);
+		uid = g_strdup (g_ptr_array_index (array, summary_index));
+	}
+
+	camel_folder_summary_free_array (array);
+
+	return uid;
+}
+
 /*
  * capability_data ::= "CAPABILITY" SPACE [1#capability SPACE] "IMAP4rev1"
  *                     [SPACE 1#capability]
@@ -373,7 +401,8 @@ struct {
 	{ "QRESYNC", IMAPX_CAPABILITY_QRESYNC },
 	{ "LIST-EXTENDED", IMAPX_CAPABILITY_LIST_EXTENDED },
 	{ "LIST-STATUS", IMAPX_CAPABILITY_LIST_STATUS },
-	{ "QUOTA", IMAPX_CAPABILITY_QUOTA }
+	{ "QUOTA", IMAPX_CAPABILITY_QUOTA },
+	{ "MOVE", IMAPX_CAPABILITY_MOVE }
 };
 
 static GMutex capa_htable_lock;         /* capabilities lookup table lock */
@@ -1834,6 +1863,27 @@ imapx_parse_status (CamelIMAPXStream *is,
 			case IMAPX_CAPABILITY:
 				sinfo->u.cinfo = imapx_parse_capability (is, cancellable, NULL);
 				break;
+
+			/* RFC 5530 Response Codes */
+			case IMAPX_ALREADYEXISTS:
+			case IMAPX_AUTHENTICATIONFAILED:
+			case IMAPX_AUTHORIZATIONFAILED:
+			case IMAPX_CANNOT:
+			case IMAPX_CLIENTBUG:
+			case IMAPX_CONTACTADMIN:
+			case IMAPX_CORRUPTION:
+			case IMAPX_EXPIRED:
+			case IMAPX_EXPUNGEISSUED:
+			case IMAPX_INUSE:
+			case IMAPX_LIMIT:
+			case IMAPX_NONEXISTENT:
+			case IMAPX_NOPERM:
+			case IMAPX_OVERQUOTA:
+			case IMAPX_PRIVACYREQUIRED:
+			case IMAPX_SERVERBUG:
+			case IMAPX_UNAVAILABLE:
+				break;
+
 			default:
 				sinfo->condition = IMAPX_UNKNOWN;
 				d (is->tagprefix, "Got unknown response code: %s: ignored\n", token);
@@ -1995,6 +2045,131 @@ imapx_free_list (struct _list_info *linfo)
 	}
 }
 
+gboolean
+camel_imapx_command_add_qresync_parameter (CamelIMAPXCommand *ic,
+                                           CamelFolder *folder)
+{
+	/* See RFC 5162 Section 3.1 */
+
+	CamelIMAPXFolder *imapx_folder;
+	CamelIMAPXSummary *imapx_summary;
+	guint64 last_known_uidvalidity;
+	guint64 last_known_modsequence;
+	guint32 last_known_message_cnt;
+	guint32 sequence_limit;
+	gchar *known_uid_set = NULL;
+	gint summary_total;
+	gboolean parameter_added = FALSE;
+
+	g_return_val_if_fail (CAMEL_IS_IMAPX_COMMAND (ic), FALSE);
+	g_return_val_if_fail (CAMEL_IS_IMAPX_FOLDER (folder), FALSE);
+
+	imapx_folder = CAMEL_IMAPX_FOLDER (folder);
+	imapx_summary = CAMEL_IMAPX_SUMMARY (folder->summary);
+
+	last_known_uidvalidity = imapx_folder->uidvalidity_on_server;
+	last_known_modsequence = imapx_summary->modseq;
+	last_known_message_cnt = imapx_folder->exists_on_server;
+
+	/* XXX This should return an unsigned integer to
+	 *     avoid the possibility of a negative count. */
+	summary_total = camel_folder_summary_count (folder->summary);
+	g_return_val_if_fail (summary_total >= 0, FALSE);
+
+	if (summary_total > 0) {
+		guint last = summary_total - 1;
+		gchar *begin, *end;
+
+		begin = camel_imapx_dup_uid_from_summary_index (folder, 0);
+		end = camel_imapx_dup_uid_from_summary_index (folder, last);
+
+		if (begin != NULL && end != NULL)
+			known_uid_set = g_strconcat (begin, ":", end, NULL);
+
+		g_free (begin);
+		g_free (end);
+	}
+
+	/* Make sure we have valid QRESYNC arguments. */
+
+	if (last_known_uidvalidity == 0)
+		goto exit;
+
+	if (last_known_modsequence == 0)
+		goto exit;
+
+	if (known_uid_set == NULL)
+		goto exit;
+
+	camel_imapx_command_add (
+		ic, " (QRESYNC (%"
+		G_GUINT64_FORMAT " %"
+		G_GUINT64_FORMAT " %s",
+		last_known_uidvalidity,
+		last_known_modsequence,
+		known_uid_set);
+
+	/* Add message sequence match data if we have enough messages. */
+
+	/* XXX Some IMAP servers like Zimbra can't handle invalid sequence
+	 *     numbers in the optional seq/uid list.  So limit the list to
+	 *     the lesser of the last known message count according to the
+	 *     server and our own summary count. */
+	sequence_limit = MIN (last_known_message_cnt, summary_total);
+
+	if (sequence_limit > 10) {
+		GString *seqs;
+		GString *uids;
+		guint32 ii = 3;
+
+		seqs = g_string_sized_new (256);
+		uids = g_string_sized_new (256);
+
+		/* Include some seq/uid pairs to avoid a huge VANISHED list.
+		 * Work backwards exponentially from the end of the mailbox,
+		 * starting with message 9 from the end, then 27 from the
+		 * end, then 81 from the end, etc. */
+		do {
+			guint32 summary_index;
+			gchar buf[10];
+			gchar *uid;
+
+			ii = MIN (ii * 3, sequence_limit);
+			summary_index = sequence_limit - ii;
+
+			if (seqs->len > 0)
+				g_string_prepend_c (seqs, ',');
+
+			if (uids->len > 0)
+				g_string_prepend_c (uids, ',');
+
+			/* IMAP sequence numbers are 1-based,
+			 * but our folder summary is 0-based. */
+			sprintf (buf, "%" G_GUINT32_FORMAT, summary_index + 1);
+
+			uid = camel_imapx_dup_uid_from_summary_index (
+				folder, summary_index);
+			if (uid != NULL) {
+				g_string_prepend (seqs, buf);
+				g_string_prepend (uids, uid);
+				g_free (uid);
+			}
+		} while (ii < sequence_limit);
+
+		camel_imapx_command_add (
+			ic, " (%s %s)", seqs->str, uids->str);
+	}
+
+	camel_imapx_command_add (ic, "))");
+
+	parameter_added = TRUE;
+
+exit:
+	g_free (known_uid_set);
+
+	return parameter_added;
+}
+
 gboolean
 camel_imapx_parse_quota (CamelIMAPXStream *is,
                          GCancellable *cancellable,
